# Components Guide

This guide provides an overview of the different components used inside Ragas.

- [Prompt Object](prompt.md)
- [Evaluation Sample](eval_sample.md)
- [Evaluation Dataset](eval_dataset.md)
